@@ -1,4 +1,5 @@
 from opwen_email_server import config
+from opwen_email_server.services.auth import Auth
 from opwen_email_server.services.auth import AzureAuth
 from opwen_email_server.services.auth import NoAuth
 from opwen_email_server.services.storage import AzureFileStorage
@@ -19,15 +20,18 @@ def get_guid_source() -> NewGuid:
 
 
 @singleton
-def get_auth() -> AzureAuth:
-    return AzureAuth(storage=AzureObjectStorage(
-        account=config.TABLES_ACCOUNT,
-        key=config.TABLES_KEY,
-        host=config.TABLES_HOST,
-        secure=config.TABLES_SECURE,
-        container=config.CONTAINER_AUTH,
-        provider=config.STORAGE_PROVIDER,
-    ))
+def get_auth() -> Auth:
+    return AzureAuth(
+        storage=AzureObjectStorage(
+            account=config.TABLES_ACCOUNT,
+            key=config.TABLES_KEY,
+            host=config.TABLES_HOST,
+            secure=config.TABLES_SECURE,
+            container=config.CONTAINER_AUTH,
+            provider=config.STORAGE_PROVIDER,
+        ),
+        sudo_scope=config.REGISTRATION_SUDO_TEAM,
+    )
 
 
 @singleton
